Learn R Programming

MPLikelihoodWB (version 1.1)

mplik.wb.s: Modified profile likelihood function of Weibull shape parameter

Description

Modified profile likelihood function of Weibull shape parameter. The function considers shape parameter as parameter of interest and remaining parameters as nuisance parameters. Standard optimization procedures are required to find the estimate of shape parameter. The estimate will be less biased comparing to existing methods when sample size is considerably small.

Usage

mplik.wb.s(par, Y, X, delta)

Arguments

par

Initial value of parameters to be estimated by optimization

Y

Weibull distributed failure times

X

covariate matrix

delta

Censoring status, coded as 0(censored observation) and 1(uncersored observation) binary integer variable.

Value

Negative log likelihood of the function at given value of parameters and data. Optimization of this function will produce maximum likelihood estimate of scale parameter of Extreme value distribution. Transformation will be required to obtain estimate of Weibull shape parameter.

References

Barndorff-Nielsen (1980). Conditionality resolutions. Biometrika, 67(2) : 293-310.

Barndorff-Nielsen (1983). On a formula for the distribution of the maximum likelihood estimator. Biometrika, 70(2) : 343-365.

Khan M. H. R. and Shaw J. E. H (2016). Variable selection for survival data with a class of adaptive elastic net techniques. Statistics and Computing, 26(3): 725-741.

Islam, M. M., Khan, M. H. R. and Hawlader T. (2015). Modified profile likelihood estimation for the weibull regression models in survival analysis. Submitted.

See Also

mplik.wb.bi

Examples

Run this code
# NOT RUN {
dat <- data.weibull(n = 40, shape=2, regco=c(2,1.5,3,2.5))

mplik.wb.s(par=c(1,1,1,1,1,1),Y=dat$ftime,X=model.matrix(ftime~x1+x2+x3+x4,data=dat),
delta=dat$delta)
# }

Run the code above in your browser using DataLab